@@ -44,7 +44,7 @@ use PPIx::Regexp;
 use PPIx::Regexp::Tokenizer;
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 =head2 new
 
@@ -76,6 +76,11 @@ specified, it is passed through to
 L<< PPIx::Regexp->new()|PPIx::Regexp/new >>. It also causes an
 C<Encode::encode> to be done on any parse content dumped.
 
+=item explain boolean
+
+If true, this option causes the C<explain()> output of each object to be
+dumped.
+
 =item indent number
 
 This argument is the number of additional spaces to indent each level of
@@ -103,6 +108,11 @@ If true, this option causes the C<perl_version_introduced> and
 C<perl_version_removed> values associated with each object dumped to be
 displayed.
 
+=item postderef boolean
+
+If true, postfix dereferences are recognized in code and interpolations.
+See the tokenizer's L<new()|PPIx::Regexp::Tokenizer/new> for details.
+
 =item significant boolean
 
 If true, this option causes only significant elements to be dumped.
@@ -154,6 +164,7 @@ ignored.
 {
 
     my %default = (
+	explain	=> 0,
 	indent	=> 2,
 	margin	=> 0,
 	ordinal	=> 0,
@@ -175,8 +186,10 @@ ignored.
 	    source => $re,
 	};
 
-	exists $args{default_modifiers}
-	    and $self->{default_modifiers} = $args{default_modifiers};
+	foreach my $key ( qw{ default_modifiers postderef } ) {
+	    exists $args{$key}
+		and $self->{$key} = $args{$key};
+	}
 
 	foreach my $key ( keys %default ) {
 	    $self->{$key} = exists $args{$key} ?
@@ -340,11 +353,16 @@ sub _tokens_dump {
 
 sub _format_default_modifiers {
     my ( $self, $subr, $elem ) = @_;
-    my $default_modifiers = $self->{default_modifiers} || [];
-    @{ $default_modifiers }
-	or return sprintf '%-8s( %s );', $subr, $self->_safe( $elem );
-    return sprintf '%-8s( %s, default_modifiers => %s );', $subr,
-	$self->_safe( $elem ), $self->_safe( $default_modifiers );
+    my @arg = $self->_safe( $elem );
+    foreach my $attr ( qw{ default_modifiers postderef } ) {
+	defined ( my $val = $self->{$attr} )
+	    or next;
+	'ARRAY' eq ref $val
+	    and not @{ $val }
+	    and next;
+	push @arg, "$attr => @{[ $self->_safe( $val ) ]}";
+    }
+    return sprintf '%-8s( %s );', $subr, join ', ', @arg;
 }
 
 sub _format_modifiers_dump {
@@ -382,6 +400,23 @@ sub _tokens_test {
     return @rslt;
 }
 
+sub PPIx::Regexp::Element::__PPIX_DUMPER__dump_explanation {
+    my ( $self, $dumper, $line ) = @_;
+    my @expl = $self->explain()
+	or return $line;
+    1 == @expl
+	and return "$line\t$expl[0]";
+    wantarray
+	or return sprintf "%s\t%s", $line, join '; ', @expl;
+    ( my $blank = $line ) =~ s/\S/ /smxg;
+    my @rslt;
+    foreach my $splain ( @expl ) {
+	push @rslt, "$line\t$splain";
+	$line = $blank;
+    }
+    return @rslt;
+}
+
 sub PPIx::Regexp::__PPIX_DUMPER__test {
     my ( $self, $dumper ) = @_;
 
@@ -420,6 +455,10 @@ sub PPIx::Regexp::Node::__PPIX_DUMPER__dump {
 	    : sprintf "\tfailures=%d", $self->failures();
     $dumper->{perl_version}
 	and $rslt[-1] .= "\t" . $dumper->_perl_version( $self );
+    $dumper->{explain}
+	and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
+	    $dumper, pop @rslt );
+
     my $indent = ' ' x $dumper->{indent};
     foreach my $elem ( $self->children() ) {
 	push @rslt, map { $indent . $_ } $elem->__PPIX_DUMPER__dump( $dumper );
@@ -508,6 +547,10 @@ sub _format_value {
 		push @rslt, $err;
 	    }
 	}
+	@rslt = ( join "\t", @rslt );
+	$dumper->{explain}
+	    and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
+		$dumper, pop @rslt );
 
 	@rslt = ( join( "\t", @rslt ) );
 	my $indent = ' ' x $dumper->{indent};
@@ -573,13 +616,15 @@ sub PPIx::Regexp::Tokenizer::__PPIX_DUMPER__test {
 sub PPIx::Regexp::Token::__PPIX_DUMPER__dump {
     my ( $self, $dumper ) = @_;
 
-    not $dumper->{significant} or $self->significant() or return;
+    not $dumper->{significant}
+	or $self->significant()
+	or return;
 
     my @rslt = ( ref $self, $dumper->_safe( $self ) );
 
     if ( defined( my $err = $self->error() ) ) {
 
-	push @rslt, $err;
+	return join "\t", @rslt, $err;
 
     } else {
 
@@ -618,8 +663,14 @@ sub PPIx::Regexp::Token::__PPIX_DUMPER__dump {
 	    }
 
 	}
+
+	@rslt = ( join "\t", @rslt );
+
+	$dumper->{explain}
+	    and push @rslt, $self->__PPIX_DUMPER__dump_explanation(
+		$dumper, pop @rslt );
+	return @rslt;
     }
-    return join( "\t", @rslt );
 }
 
 sub PPIx::Regexp::Token::__PPIX_DUMPER__test {
