@@ -52,7 +52,7 @@ use PPIx::Regexp::Constant qw{ STRUCTURE_UNKNOWN };
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ refaddr };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 sub _new {
     my ( $class, @args ) = @_;
@@ -131,6 +131,17 @@ sub elements {
     }
 }
 
+sub explain {
+    my ( $self ) = @_;
+    if ( my $type = $self->type() ) {
+	return $type->explain();
+    }
+    if ( my $start = $self->start() ) {
+	return $start->explain();
+    }
+    return $self->__no_explanation();
+}
+
 =head2 finish
 
  my $elem = $struct->finish();
