@@ -35,7 +35,12 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
+
+sub explain {
+    my ( $self ) = @_;
+    return sprintf q<Capture group number %s>, $self->number();
+}
 
 =head2 name
 
