@@ -36,7 +36,7 @@ use base qw{ PPIx::Regexp::Structure };
 
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 sub _new {
     my ( $class, @args ) = @_;
@@ -50,6 +50,13 @@ sub _new {
     return $class->SUPER::_new( \%brkt, @args );
 }
 
+sub explain {
+    my ( $self ) = @_;
+    $self->negated()
+	and return 'Inverted character class';
+    return 'Character class';
+}
+
 =head2 negated
 
  $class->negated() and print "Class is negated\n";
