@@ -41,7 +41,13 @@ use Carp;
 
 use base qw{ PPIx::Regexp::Structure::Capture };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
+
+sub explain {
+    my ( $self ) = @_;
+    return sprintf q<Named capture group '%s' (number %d)>,
+	$self->name(), $self->number();
+}
 
 =head2 name
 
