@@ -36,7 +36,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure::Main };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 sub can_be_quantified { return; }
 
@@ -62,6 +62,10 @@ sub capture_names {
     return ( sort keys %name );
 }
 
+sub explain {
+    return 'Regular expression';
+}
+
 =head2 max_capture_number
 
  print "Highest used capture number ",
