@@ -38,10 +38,14 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Structure::Main };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 sub can_be_quantified { return; }
 
+sub explain {
+    return 'Replacement string or expression';
+}
+
 1;
 
 __END__
