@@ -50,7 +50,7 @@ use PPIx::Regexp::Constant qw{
     COOKIE_CLASS MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -88,6 +88,32 @@ sub perl_version_introduced {
 
 }
 
+{
+    my %explanation = (
+	'$'	=> 'Assert position is at end of string or newline',
+	'\\A'	=> 'Assert position is at beginning of string',
+	'\\B'	=> 'Assert position is not at word/nonword boundary',
+	'\\B{gcb}'	=> 'Assert position is not at grapheme cluster boundary',
+	'\\B{g}'	=> 'Assert position is not at grapheme cluster boundary',
+	'\\B{sb}'	=> 'Assert position is not at sentence boundary',
+	'\\B{wb}'	=> 'Assert position is not at word boundary',
+	'\\G'	=> 'Assert position is at pos()',
+	'\\K'	=> 'In s///, keep everything before the \\K',
+	'\\Z'	=> 'Assert position is at end of string, or newline before end',
+	'\\b'	=> 'Assert position is at word/nonword boundary',
+	'\\b{gcb}'	=> 'Assert position is at grapheme cluster boundary',
+	'\\b{g}'	=> 'Assert position is at grapheme cluster boundary',
+	'\\b{sb}'	=> 'Assert position is at sentence boundary',
+	'\\b{wb}'	=> 'Assert position is at word boundary',
+	'\\z'	=> 'Assert position is at end of string',
+	'^'	=> 'Assert position is at beginning of string or after newline',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+}
+
 # By logic we should handle '$' here. But
 # PPIx::Regexp::Token::Interpolation needs to process it to see if it is
 # a sigil. If it is not, that module is expected to make it into an
@@ -101,7 +127,7 @@ my %assertion = map { $_ => 1 } qw{ ^ };
 my %escaped = map { $_ => 1 } qw{ b B A Z z G K };
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     # Inside a character class, these are all literals.
     my $make = $tokenizer->cookie( COOKIE_CLASS ) ?
