@@ -39,12 +39,27 @@ use PPIx::Regexp::Constant qw{
     MINIMUM_PERL RE_CAPTURE_NAME
     TOKEN_LITERAL TOKEN_UNKNOWN
 };
+use PPIx::Regexp::Util qw{ __to_ordinal_en };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+sub explain {
+    my ( $self ) = @_;
+    $self->is_named()
+	and return sprintf q<Back reference to capture group '%s'>,
+	    $self->name();
+    $self->is_relative()
+	and return sprintf
+	    q<Back reference to %s previous capture group (%d in this regexp)>,
+	    __to_ordinal_en( - $self->number() ),
+	    $self->absolute();
+    return sprintf q<Back reference to capture group %d>,
+	$self->absolute();
+}
+
 {
 
     my %perl_version_introduced = (
@@ -96,7 +111,7 @@ sub __PPIX_TOKEN__recognize {
 }
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     # PCRE/Python back references are handled in
     # PPIx::Regexp::Token::Structure, because they are parenthesized.
@@ -115,7 +130,7 @@ sub __PPIX_TOKENIZER__regexp {
 }
 
 sub __PPIX_TOKENIZER__repl {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     $tokenizer->interpolates() and goto &__PPIX_TOKENIZER__regexp;
 
