@@ -43,7 +43,7 @@ use base qw{ PPIx::Regexp::Token::CharClass };
 
 use PPIx::Regexp::Constant qw{ COOKIE_CLASS COOKIE_REGEX_SET MINIMUM_PERL };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
@@ -70,6 +70,37 @@ sub perl_version_introduced {
     return '5.006';
 }
 
+{
+
+    my %explanation = (
+	'[:alnum:]'	=> 'Any alphanumeric character',
+	'[:alpha:]'	=> 'Match alphabetic',
+	'[:ascii:]'	=> 'Any character in the ASCII character set',
+	'[:blank:]'	=> 'A GNU extension, equal to a space or a horizontal tab ("\\t")',
+	'[:cntrl:]'	=> 'Any control character',
+	'[:digit:]'	=> 'Any decimal digit ("[0-9]")',
+	'[:graph:]'	=> 'Any printable character, excluding a space',
+	'[:lower:]'	=> 'Any lowercase character',
+	'[:print:]'	=> 'Any printable character',
+	'[:punct:]'	=> 'Any graphical character excluding "word" characters',
+	'[:space:]'	=> 'Any whitespace character',
+	'[:upper:]'	=> 'Any uppercase character',
+	'[:word:]'	=> 'A Perl extension, equivalent to "\\w"',
+	'[:xdigit:]'	=> 'Any hexadecimal digit',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+    sub __no_explanation {
+	my ( $self ) = @_;
+	my $msg = sprintf q<Unknown POSIX character class>;
+	return $msg;
+    }
+
+}
+
 {
 
     my %class = (
@@ -77,7 +108,7 @@ sub perl_version_introduced {
     );
 
     sub __PPIX_TOKENIZER__regexp {
-	my ( $class, $tokenizer, $character ) = @_;
+	my ( undef, $tokenizer, $character ) = @_;
 
 	$tokenizer->cookie( COOKIE_CLASS )
 	    or $tokenizer->cookie( COOKIE_REGEX_SET )
