@@ -46,11 +46,12 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
+use Carp qw{ confess };
 use PPI::Document;
 use PPIx::Regexp::Constant qw{ COOKIE_REGEX_SET };
 use PPIx::Regexp::Util qw{ __instance };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 sub _new {
     my ( $class, $content ) = @_;
@@ -79,6 +80,10 @@ sub content {
     }
 }
 
+sub explain {
+    return 'Perl expression';
+}
+
 sub perl_version_introduced {
     my ( $self ) = @_;
     return $self->{perl_version_introduced};
@@ -115,12 +120,12 @@ sub ppi {
     sub __PPIX_TOKEN__post_make {
 	my ( $self, $tokenizer, $arg ) = @_;
 
-	$self->__impose_defaults( $arg, \%default );
+	my %override;
+	$tokenizer->__recognize_postderef( $self )
+	    and $override{perl_version_introduced} = '5.019005';
+	$self->__impose_defaults( \%override, $arg, \%default );
 
-	# If we're manufacturing objects directly (which is UNSUPPORTED,
-	# but used in t/version.t) we may not have a $tokenizer.
-	$tokenizer
-	    and $tokenizer->cookie( COOKIE_REGEX_SET )
+	$tokenizer->cookie( COOKIE_REGEX_SET )
 	    and $self->__error( 'Code token not valid in Regex set' );
 
 	return;
@@ -128,8 +133,20 @@ sub ppi {
 
 }
 
+{
+    no warnings qw{ qw };	## no critic (ProhibitNoWarnings)
+
+    my %accept = map { $_ => 1 } qw{ $ $# @ % & * };
+
+    # Say what casts are accepted, since not all are in am
+    # interpolation.
+    sub __postderef_accept_cast {
+	return \%accept;
+    }
+}
+
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     $character eq '{' or return;
 
