@@ -45,11 +45,29 @@ use PPIx::Regexp::Constant qw{
     COOKIE_QUOTE MINIMUM_PERL TOKEN_LITERAL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+{
+
+    my %explanation = (
+	'\\E'	=> 'End of interpolation control',
+	'\\F'	=> 'Fold case until \\E',
+	'\\L'	=> 'Lowercase until \\E',
+	'\\Q'	=> 'Quote metacharacters until \\E',
+	'\\U'	=> 'Uppercase until \\E',
+	'\\l'	=> 'Lowercase next character',
+	'\\u'	=> 'Uppercase next character',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+}
+
 {
     my %version_introduced = (
 	'\\F'	=> '5.015008',
@@ -71,7 +89,7 @@ my %cookie = (
 );
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     # If we are inside a quote sequence, we want to make literals out of
     # all the characters we reject; otherwise we just want to return
@@ -113,7 +131,7 @@ sub __PPIX_TOKENIZER__regexp {
 }
 
 sub __PPIX_TOKENIZER__repl {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     $tokenizer->interpolates() and goto &__PPIX_TOKENIZER__regexp;
 
