@@ -35,11 +35,15 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::Structure };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+sub explain {
+    return 'Regular expression or replacement string delimiter';
+}
+
 1;
 
 __END__
