@@ -37,11 +37,24 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
 
+{
+
+    my %explanation = (
+	'+'	=> 'match longest string and give nothing back',
+	'?'	=> 'match shortest string first',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+}
+
 my %greediness = (
     '?' => MINIMUM_PERL,
     '+' => '5.009005',
@@ -67,7 +80,7 @@ sub perl_version_introduced {
 }
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character, $char_type ) = @_;
+    my ( undef, $tokenizer, $character, $char_type ) = @_;
 
     $tokenizer->prior( 'is_quantifier' ) or return;
 
