@@ -36,9 +36,25 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 {
+
+    my %explanation = (
+	'?!'	=> 'Negative look-ahead assertion',
+	'?<!'	=> 'Negative look-behind assertion',
+	'?<='	=> 'Positive look-behind assertion',
+	'?='	=> 'Positive look-ahead assertion',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+}
+
+{
+
     my %perl_version_introduced = (
 	'?<='	=> '5.005',
 	'?<!'	=> '5.005',
