@@ -34,11 +34,21 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+{
+    my %explanation = (
+	'?|'	=> 'Re-use capture group numbers',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+}
+
 sub perl_version_introduced {
     return '5.009005';
 }
