@@ -43,11 +43,25 @@ use base qw{ PPIx::Regexp::Token::GroupType };
 
 use PPIx::Regexp::Constant qw{ MINIMUM_PERL };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+{
+
+    my %explanation = (
+	'??'	=> 'Evaluate code, use as regexp at this point',
+	'?p'	=> 'Evaluate code, use as regexp at this point (removed in 5.9.5)',
+	'?'		=> 'Evaluate code. Always matches.',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+}
+
 {
     my %perl_version_introduced = (
 	'?'	=> '5.005',
