@@ -35,7 +35,18 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token::GroupType };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
+
+{
+
+    my %explanation = (
+	'?'	=> q<Match one of the following '|'-delimited alternatives>,
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+}
 
 sub perl_version_introduced {
 #   my ( $self ) = @_;
