@@ -38,11 +38,15 @@ use PPIx::Regexp::Constant qw{
     COOKIE_CLASS COOKIE_REGEX_SET MINIMUM_PERL TOKEN_UNKNOWN
 };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 # sub can_be_quantified { return };
 
+sub explain {
+    return 'Literal character';
+}
+
 sub perl_version_introduced {
     my ( $self ) = @_;
     exists $self->{perl_version_introduced}
@@ -122,7 +126,7 @@ $white_space_re = eval $white_space_re;  ## no critic (ProhibitStringyEval)
 my %regex_pass_on = map { $_ => 1 } qw{ [ ] ( ) $ \ };
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character, $char_type ) = @_;
+    my ( undef, $tokenizer, $character, $char_type ) = @_;
 
     if ( $tokenizer->cookie( COOKIE_REGEX_SET ) ) {
 	# If we're inside a regex set no literals are allowed, but not
