@@ -35,7 +35,7 @@ use warnings;
 
 use base qw{ PPIx::Regexp::Token };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 sub can_be_quantified { return };
@@ -59,8 +59,22 @@ sub could_be_quantifier {
     return $quantifier{$string};
 }
 
+{
+
+    my %explanation = (
+	'*'	=> 'match zero or more times',
+	'+'	=> 'match one or more times',
+	'?'	=> 'match zero or one time',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+}
+
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( undef, $tokenizer, $character ) = @_;
 
     $tokenizer->prior( 'can_be_quantified' )
 	or return;
