@@ -42,7 +42,7 @@ use base qw{ PPIx::Regexp::Token };
 use Carp qw{ confess };
 use List::Util qw{ first };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 =head2 absolute
 
@@ -161,9 +161,9 @@ sub __PPIX_TOKEN__post_make {
 
     my $capture;
     if ( defined $arg ) {
-	$tokenizer
-	    and $capture = first { defined $_ } $tokenizer->capture();
-	defined $capture or $capture = $arg->{capture};
+	$capture = first { defined $_ } $tokenizer->capture();
+	defined $capture
+	    or $capture = $arg->{capture};
     } else {
 	my $content = $self->content();
 	foreach ( $self->__PPIX_TOKEN__recognize() ) {
