@@ -53,7 +53,7 @@ use PPIx::Regexp::Token::Backreference	();
 use PPIx::Regexp::Token::Backtrack	();
 use PPIx::Regexp::Token::Recursion	();
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 # Return true if the token can be quantified, and false otherwise
 
@@ -64,6 +64,29 @@ sub can_be_quantified {
     return $quant{ $self->content() };
 };
 
+{
+
+    my %explanation = (
+	''		=> 'Match regexp',
+	'('		=> 'Capture or grouping',
+	'(?['	=> 'Extended character class',
+	')'		=> 'End capture or grouping',
+	'['		=> 'Character class',
+	']'		=> 'End character class',
+	'])'	=> 'End extended character class',
+	'm'		=> 'Match regexp',
+	'qr'	=> 'Regexp object definition',
+	's'	=> 'Replace regexp with string or expression',
+	'{'		=> 'Explicit quantifier',
+	'}'		=> 'End explicit quantifier',
+    );
+
+    sub __explanation {
+	return \%explanation;
+    }
+
+}
+
 sub is_quantifier {
     my ( $self ) = @_;
     ref $self or return;
@@ -110,7 +133,7 @@ sub is_quantifier {
     ;
 
     sub __PPIX_TOKENIZER__regexp {
-	my ( $class, $tokenizer, $character ) = @_;
+	my ( undef, $tokenizer, $character ) = @_;
 
 	# We are not interested in anything but delimiters.
 	$delim{$character} or return;
