@@ -39,7 +39,24 @@ use base qw{ PPIx::Regexp::Token };
 
 use PPIx::Regexp::Constant qw{ COOKIE_REGEX_SET MINIMUM_PERL };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
+
+sub explain {
+    my ( $self ) = @_;
+    my $parent;
+    if (
+	$parent = $self->parent()
+	    and $parent->isa( 'PPIx::Regexp' )
+    ) {
+	    return 'Not significant';
+    } elsif ( $self->in_regex_set() ) {
+	return q<Not significant in extended character class>;
+    } elsif ( $self->modifier_asserted( 'x' ) ) {
+	return q<Not significant under /x>;
+    } else {
+	return 'Not significant';
+    }
+}
 
 sub perl_version_introduced {
     my ( $self ) = @_;
