@@ -42,7 +42,11 @@ use PPIx::Regexp::Token::Whitespace		();
 use PPIx::Regexp::Util qw{ __instance };
 use Scalar::Util qw{ looks_like_number };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
+
+our $DEFAULT_POSTDEREF;
+defined $DEFAULT_POSTDEREF
+    or $DEFAULT_POSTDEREF = 0;
 
 {
     # Names of classes containing tokenization machinery. There are few
@@ -115,9 +119,7 @@ our $VERSION = '0.042_05';
     sub _known_tokenizer_check {
 	my ( $self, @args ) = @_;
 
-	my $mode = $self->{mode};
-
-	my $handler = '__PPIX_TOKENIZER__' . $mode;
+	my $handler = '__PPIX_TOKENIZER__' . $self->{mode};
 	my @found;
 
 	foreach my $class ( @args ) {
@@ -173,6 +175,9 @@ our $VERSION = '0.042_05';
 	    mode => 'init',	# Initialize
 	    modifiers => [{}],	# Modifier hash.
 	    pending => [],	# Tokens made but not returned.
+	    postderef => defined $args{postderef} ?
+		$args{postderef} :
+		$DEFAULT_POSTDEREF,
 	    prior => TOKEN_UNKNOWN,	# Prior significant token.
 	    source => $re,	# The object we were initialized with.
 	    trace => __PACKAGE__->_defined_or(
@@ -368,7 +373,7 @@ sub get_token {
 
     my $handler = '__PPIX_TOKENIZER__' . $self->{mode};
 
-    __PACKAGE__->can( $handler )
+    my $code = $self->can( $handler )
 	or confess "Getting token in mode '$self->{mode}'. ",
 	    "cursor_curr = $self->{cursor_curr}; ",
 	    "cursor_limit = $self->{cursor_limit}; ",
@@ -383,7 +388,7 @@ sub get_token {
     $self->{trace}
 	and warn "get_token() got '$character' from $self->{cursor_curr}\n";
 
-    return ( __PACKAGE__->$handler( $self, $character ) );
+    return ( $code->( $self, $character ) );
 }
 
 sub interpolates {
@@ -531,6 +536,121 @@ sub prior {
     return $self->{prior}->$method( @args );
 }
 
+# my $length = $token->__recognize_postderef( $tokenizer, $iterator ).
+#
+# This method is private to the PPIx-Regexp package, and may be changed
+# or retracted without warning. What it does is to recognize postfix
+# dereferences. It returns the length in characters of the first postfix
+# dereference found, or a false value if none is found. This returns
+# false immediately unless the tokenizer was instantiated with the
+# C<postderef> argument true, or if it was not specified and
+# C<$DEFAULT_POSTDEREF> was true when the tokenizer was instantiated.
+#
+# The optional $iterator argument can be one of the following:
+#   - A code reference, which will be called to provide PPI::Element
+#     objects to be checked to see if they represent a postfix
+#     dereference.
+#   - A PPI::Element, which is checked to see if it is a postfix
+#     dereference.
+#   - Undef, or omitted, in which case ppi() is called on the invocant,
+#     and everything that follows the '->' operator is checked to see if
+#     it is a postfix dereference.
+#   - Anything else results in an exception and stack trace.
+
+{
+    # %* &* **
+    my %magic_var = map { $_ => 1 } qw{ @* $* };
+    my %magic_oper = map { $_ => 1 } qw{ & ** % };
+    my %sliceable = map { $_ => 1 } qw{ @ % };
+    my %post_slice = map { $_ => 1 } qw< { [ >;	# ] }
+
+    sub __recognize_postderef {
+	my ( $self, $token, $iterator ) = @_;
+	$self->{postderef}
+	    or return;
+	# Note that if ppi() gets called I have to hold a reference to
+	# the returned object until I am done with all its children.
+	my $ppi;
+	if ( ! defined $iterator ) {
+	    $ppi = $token->ppi();
+	    my @ops = grep { '->' eq $_->content() } @{
+		$ppi->find( 'PPI::Token::Operator' ) || [] };
+	    $iterator = sub {
+		my $op = shift @ops
+		    or return;
+		return $op->snext_sibling();
+	    };
+	} elsif ( $iterator->isa( 'PPI::Element' ) ) {
+	    my @eles = ( $iterator );
+	    $iterator = sub {
+		return shift @eles;
+	    };
+	} elsif ( 'CODE' ne ref $iterator ) {
+	    confess 'Programming error - Iterator not understood';
+	}
+
+	my $accept = $token->__postderef_accept_cast();
+
+	while ( my $elem = $iterator->() ) {
+
+	    my $content = $elem->content();
+	    $content =~ m/ \A ( . \#? ) /smx
+		and $accept->{$1}
+		or next;
+
+	    my $length = length $content;
+
+	    # PPI parses '$x->@*' as containing magic variable '@*'.
+	    # Similarly for '$*' and '$#*'. I think this is a bug, and
+	    # they should be parsed as casts, but ...
+	    if ( $elem->isa( 'PPI::Token::Magic' ) ) {
+		$magic_var{$content}
+		    and return $length;
+		if ( '$#' eq $content ) {
+		    my $next = $elem->snext_sibling()
+			or return $length;
+		    '*' eq substr $next->content(), 0, 1
+			and return $length + 1;
+		}
+	    }
+
+	    # PPI parses '%*' as a cast of '%' followed by a splat, but
+	    # I think it is likely that if it ever supports postderef
+	    # operators that they will be casts. It currently parses
+	    # '**' as an operator and '&*' as two operators, but the
+	    # logic is pretty much the same as for a cast, so they get
+	    # handled here too.
+	    if ( $elem->isa( 'PPI::Token::Cast' ) || $elem->isa(
+		    'PPI::Token::Operator' ) && $magic_oper{$content} ) {
+		# Maybe PPI will eventually parse something like '$*' as
+		# a cast, so ...
+		$content =~ m/ [*] \z /smx
+		    and return $length;
+		# Or maybe it will parse the asterisk separately, but I
+		# have no idea what its class will be.
+		my $next = $elem->snext_sibling()
+		    or return;
+		my $next_content = $next->content();
+		my $next_char = substr $next_content, 0, 1;
+		'*' eq $next_char
+		    and return $length + 1;
+		# We may still have a slice.
+		$sliceable{$content}
+		    and $post_slice{$next_char}
+		    and return $length + length $next_content;
+		# TODO maybe PPI will do something completely
+		# unanticipated with postderef.
+	    }
+
+	    # Otherwise, we're not a postfix dereference; try the next
+	    # iteration.
+	}
+
+	# No postfix dereference found.
+	return;
+    }
+}
+
 sub significant {
     return 1;
 }
@@ -578,148 +698,147 @@ sub _set_mode {
 }
 
 sub __PPIX_TOKENIZER__init {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $self, $character ) = @_;
 
-    $tokenizer->{content} =~ m/ \A \s* ( qr | m | s )? ( \s* ) ( [^\w\s] ) /smx
-	or return $tokenizer->_make_final_token(
-	    length( $tokenizer->{content} ), TOKEN_UNKNOWN, {
+    $self->find_regexp(
+	qr{ \A ( \s* ) ( qr | m | s )? ( \s* ) (?: [^\w\s] ) }smx )
+	or return $self->_make_final_token(
+	    length( $self->{content} ), TOKEN_UNKNOWN, {
 		error	=> 'Tokenizer found illegal first characters',
 	    },
 	);
-#   my ( $type, $white, $delim ) = ( $1, $2, $3 );
-    my ( $type, $white ) = ( $1, $2 );
-    my $start_pos = defined $-[1] ? $-[1] :
-	defined $-[2] ? $-[2] :
-	defined $-[3] ? $-[3] : 0;
 
-    defined $type or $type = '';
-    $tokenizer->{type} = $type;
+    my ( $leading_white, $type, $next_white ) = $self->capture();
+
+    defined $type
+	or $type = '';
 
     my @tokens;
-    $start_pos
-	and push @tokens, $tokenizer->make_token( $start_pos,
+
+    '' ne $leading_white
+	and push @tokens, $self->make_token( length $leading_white,
 	'PPIx::Regexp::Token::Whitespace' );
-    push @tokens, $tokenizer->make_token( length $type,
+    push @tokens, $self->make_token( length $type,
 	'PPIx::Regexp::Token::Structure' );
-    length $white > 0
-	and push @tokens, $tokenizer->make_token( length $white,
+    '' ne $next_white
+	and push @tokens, $self->make_token( length $next_white,
 	'PPIx::Regexp::Token::Whitespace' );
 
-    $tokenizer->{delimiter_start} = substr
-	$tokenizer->{content},
-	$tokenizer->{cursor_curr},
+    $self->{delimiter_start} = substr
+	$self->{content},
+	$self->{cursor_curr},
 	1;
 
-    $tokenizer->{trace}
-	and warn "Tokenizer found regexp start delimiter '$tokenizer->{delimiter_start}' at $tokenizer->{cursor_curr}\n";
+    $self->{trace}
+	and warn "Tokenizer found regexp start delimiter '$self->{delimiter_start}' at $self->{cursor_curr}\n";
 
-    if ( my $offset = $tokenizer->find_matching_delimiter() ) {
-	my $cursor_limit = $tokenizer->{cursor_curr} + $offset;
-	$tokenizer->{trace}
+    if ( my $offset = $self->find_matching_delimiter() ) {
+	my $cursor_limit = $self->{cursor_curr} + $offset;
+	$self->{trace}
 	    and warn "Tokenizer found regexp end delimiter at $cursor_limit\n";
 	if ( 's' eq $type ) {
-	    if ( $tokenizer->close_bracket(
-		    $tokenizer->{delimiter_start} ) ) {
-		pos $tokenizer->{content} = $tokenizer->{cursor_curr} +
+	    if ( $self->close_bracket(
+		    $self->{delimiter_start} ) ) {
+		pos $self->{content} = $self->{cursor_curr} +
 		$offset + 1;
-		$tokenizer->{content} =~ m/ \s* /smxgc;
+		$self->{content} =~ m/ \s* /smxgc;
 	    } else {
-		pos $tokenizer->{content} = $tokenizer->{cursor_curr} +
+		pos $self->{content} = $self->{cursor_curr} +
 		$offset;
 	    }
-	    local $tokenizer->{cursor_curr} = pos $tokenizer->{content};
-	    local $tokenizer->{delimiter_start} = substr
-		$tokenizer->{content},
-		$tokenizer->{cursor_curr},
+	    local $self->{cursor_curr} = pos $self->{content};
+	    local $self->{delimiter_start} = substr
+		$self->{content},
+		$self->{cursor_curr},
 		1;
-	    $tokenizer->{trace}
-		and warn "Tokenizer found replacemebt start delimiter '$tokenizer->{delimiter_start}' at $tokenizer->{cursor_curr}\n";
-	    if ( my $s_off = $tokenizer->find_matching_delimiter() ) {
-		$tokenizer->{cursor_modifiers} =
-		    $tokenizer->{cursor_curr} + $s_off + 1;
-		$tokenizer->{trace}
+	    $self->{trace}
+		and warn "Tokenizer found replacement start delimiter '$self->{delimiter_start}' at $self->{cursor_curr}\n";
+	    if ( my $s_off = $self->find_matching_delimiter() ) {
+		$self->{cursor_modifiers} =
+		    $self->{cursor_curr} + $s_off + 1;
+		$self->{trace}
 		    and warn "Tokenizer found replacement end delimiter at @{[
-			$tokenizer->{cursor_curr} + $s_off ]}\n";
+			$self->{cursor_curr} + $s_off ]}\n";
 	    } else {
-		$tokenizer->{cursor_curr} = 0;
-		return $tokenizer->_make_final_token(
-		    length( $tokenizer->{content} ), TOKEN_UNKNOWN, {
+		$self->{cursor_curr} = 0;
+		return $self->_make_final_token(
+		    length( $self->{content} ), TOKEN_UNKNOWN, {
 			error	=> 'Tokenizer found mismatched replacement delimiters',
 		    },
 		);
 	    }
 	} else {
-	    $tokenizer->{cursor_modifiers} = $cursor_limit + 1;
+	    $self->{cursor_modifiers} = $cursor_limit + 1;
 	}
-	$tokenizer->{cursor_limit} = $cursor_limit;
+	$self->{cursor_limit} = $cursor_limit;
     } else {
-	$tokenizer->{cursor_curr} = 0;
-	return $tokenizer->_make_final_token(
-	    length( $tokenizer->{content} ), TOKEN_UNKNOWN, {
+	$self->{cursor_curr} = 0;
+	return $self->_make_final_token(
+	    length( $self->{content} ), TOKEN_UNKNOWN, {
 		error	=> 'Tokenizer found mismatched regexp delimiters',
 	    },
 	);
     }
 
     {
-	my @mods = @{ $tokenizer->{default_modifiers} };
-	pos $tokenizer->{content} = $tokenizer->{cursor_modifiers};
-	local $tokenizer->{cursor_curr} = $tokenizer->{cursor_modifiers};
-	local $tokenizer->{cursor_limit} = length $tokenizer->{content};
+	my @mods = @{ $self->{default_modifiers} };
+	pos $self->{content} = $self->{cursor_modifiers};
+	local $self->{cursor_curr} = $self->{cursor_modifiers};
+	local $self->{cursor_limit} = length $self->{content};
 	my @trailing;
 	{
-	    my $len = $tokenizer->find_regexp( qr{ \A [[:lower:]]* }smx );
-	    push @trailing, $tokenizer->make_token( $len,
+	    my $len = $self->find_regexp( qr{ \A [[:lower:]]* }smx );
+	    push @trailing, $self->make_token( $len,
 		'PPIx::Regexp::Token::Modifier' );
 	}
-	if ( my $len = $tokenizer->find_regexp( qr{ \A \s+ }smx ) ) {
-	    push @trailing, $tokenizer->make_token( $len,
+	if ( my $len = $self->find_regexp( qr{ \A \s+ }smx ) ) {
+	    push @trailing, $self->make_token( $len,
 		'PPIx::Regexp::Token::Whitespace' );
 	}
-	if ( my $len = $tokenizer->find_regexp( qr{ \A .+ }smx ) ) {
-	    push @trailing, $tokenizer->make_token( $len, TOKEN_UNKNOWN, {
+	if ( my $len = $self->find_regexp( qr{ \A .+ }smx ) ) {
+	    push @trailing, $self->make_token( $len, TOKEN_UNKNOWN, {
 		    error	=> 'Trailing characters after expression',
 		} );
 	}
-	$tokenizer->{trailing_tokens} = \@trailing;
+	$self->{trailing_tokens} = \@trailing;
 	push @mods, $trailing[0]->content();
-	$tokenizer->{effective_modifiers} =
+	$self->{effective_modifiers} =
 	    PPIx::Regexp::Token::Modifier::__aggregate_modifiers (
 		@mods );
-	$tokenizer->{modifiers} = [
-	    { %{ $tokenizer->{effective_modifiers} } },
+	$self->{modifiers} = [
+	    { %{ $self->{effective_modifiers} } },
 	];
     }
 
-    $tokenizer->{delimiter_finish} = substr
-	$tokenizer->{content},
-	$tokenizer->{cursor_limit},
+    $self->{delimiter_finish} = substr
+	$self->{content},
+	$self->{cursor_limit},
 	1;
-    $tokenizer->{delimiter_re} = undef;
+    $self->{delimiter_re} = undef;
 
-    push @tokens, $tokenizer->make_token( 1,
+    push @tokens, $self->make_token( 1,
 	'PPIx::Regexp::Token::Delimiter' );
 
-    $tokenizer->_set_mode( 'regexp' );
+    $self->_set_mode( 'regexp' );
 
     return @tokens;
 }
 
 sub __PPIX_TOKENIZER__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $self, $character ) = @_;
 
-    my $mode = $tokenizer->{mode};
+    my $mode = $self->{mode};
     my $handler = '__PPIX_TOKENIZER__' . $mode;
 
-    $tokenizer->{cursor_orig} = $tokenizer->{cursor_curr};
-    foreach my $class( $tokenizer->_known_tokenizers() ) {
-	my @tokens = grep { $_ } $class->$handler( $tokenizer, $character );
-	$tokenizer->{trace}
-	    and warn $class, "->$handler( \$tokenizer, '$character' )",
+    $self->{cursor_orig} = $self->{cursor_curr};
+    foreach my $class ( $self->_known_tokenizers() ) {
+	my @tokens = grep { $_ } $class->$handler( $self, $character );
+	$self->{trace}
+	    and warn $class, "->$handler( \$self, '$character' )",
 		" => (@tokens)\n";
 	@tokens
 	    and return ( map {
-		ref $_ ? $_ : $tokenizer->make_token( $_,
+		ref $_ ? $_ : $self->make_token( $_,
 		    $class ) } @tokens );
     }
 
@@ -727,106 +846,106 @@ sub __PPIX_TOKENIZER__regexp {
     my $fallback = __PACKAGE__->can( '__PPIX_TOKEN_FALLBACK__' . $mode )
 	|| __PACKAGE__->can( '__PPIX_TOKEN_FALLBACK__regexp' )
 	|| confess "Programming error - unable to find fallback for $mode";
-    return $fallback->( $class, $tokenizer, $character );
+    return $fallback->( $self, $character );
 }
 
 *__PPIX_TOKENIZER__repl = \&__PPIX_TOKENIZER__regexp;
 
 sub __PPIX_TOKEN_FALLBACK__regexp {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $self, $character ) = @_;
 
     # As a fallback in regexp mode, any escaped character is a literal.
     if ( $character eq '\\'
-	&& $tokenizer->{cursor_limit} - $tokenizer->{cursor_curr} > 1
+	&& $self->{cursor_limit} - $self->{cursor_curr} > 1
     ) {
-	return $tokenizer->make_token( 2, TOKEN_LITERAL );
+	return $self->make_token( 2, TOKEN_LITERAL );
     }
 
     # Any normal character is unknown.
-    return $tokenizer->make_token( 1, TOKEN_UNKNOWN, {
+    return $self->make_token( 1, TOKEN_UNKNOWN, {
 	    error	=> 'Tokenizer found unexpected literal',
 	},
     );
 }
 
 sub __PPIX_TOKEN_FALLBACK__repl {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $self, $character ) = @_;
 
     # As a fallback in replacement mode, any escaped character is a literal.
     if ( $character eq '\\'
-	&& defined ( my $next = $tokenizer->peek( 1 ) ) ) {
+	&& defined ( my $next = $self->peek( 1 ) ) ) {
 
-	if ( $tokenizer->interpolates() || $next eq q<'> || $next eq '\\' ) {
-	    return $tokenizer->make_token( 2, TOKEN_LITERAL );
+	if ( $self->interpolates() || $next eq q<'> || $next eq '\\' ) {
+	    return $self->make_token( 2, TOKEN_LITERAL );
 	}
-	return $tokenizer->make_token( 1, TOKEN_LITERAL );
+	return $self->make_token( 1, TOKEN_LITERAL );
     }
 
     # So is any normal character.
-    return $tokenizer->make_token( 1, TOKEN_LITERAL );
+    return $self->make_token( 1, TOKEN_LITERAL );
 }
 
 sub __PPIX_TOKENIZER__finish {
-    my ( $class, $tokenizer, $character ) = @_;
+    my ( $self, $character ) = @_;
 
-    $tokenizer->{cursor_limit} > length $tokenizer->{content}
+    $self->{cursor_limit} > length $self->{content}
 	and confess "Programming error - ran off string";
-    my @tokens = $tokenizer->make_token( 1,
+    my @tokens = $self->make_token( 1,
 	'PPIx::Regexp::Token::Delimiter' );
 
-    if ( $tokenizer->{cursor_curr} == $tokenizer->{cursor_modifiers} ) {
+    if ( $self->{cursor_curr} == $self->{cursor_modifiers} ) {
 
 	# We are out of string. Add the trailing tokens (created when we
 	# did the initial bracket scan) and close up shop.
 
-	push @tokens, @{ delete $tokenizer->{trailing_tokens} };
+	push @tokens, @{ delete $self->{trailing_tokens} };
 
-	$tokenizer->_set_mode( 'kaput' );
+	$self->_set_mode( 'kaput' );
 
     } else {
 
 	# Clear the cookies, because we are going around again.
-	$tokenizer->{cookie} = {};
+	$self->{cookie} = {};
 
 	# Move the cursor limit to just before the modifiers.
-	$tokenizer->{cursor_limit} = $tokenizer->{cursor_modifiers} - 1;
+	$self->{cursor_limit} = $self->{cursor_modifiers} - 1;
 
 	# If the preceding regular expression was bracketed, we need to
 	# consume possible whitespace and find another delimiter.
 
-	if ( $tokenizer->close_bracket( $tokenizer->{delimiter_start} ) ) {
+	if ( $self->close_bracket( $self->{delimiter_start} ) ) {
 	    my $accept;
-	    $accept = $tokenizer->find_regexp( qr{ \A \s+ }smx )
-		and push @tokens, $tokenizer->make_token(
+	    $accept = $self->find_regexp( qr{ \A \s+ }smx )
+		and push @tokens, $self->make_token(
 		$accept, 'PPIx::Regexp::Token::Whitespace' );
-	    my $character = $tokenizer->peek();
-	    $tokenizer->{delimiter_start} = $character;
-	    push @tokens, $tokenizer->make_token(
+	    my $character = $self->peek();
+	    $self->{delimiter_start} = $character;
+	    push @tokens, $self->make_token(
 		1, 'PPIx::Regexp::Token::Delimiter' );
-	    $tokenizer->{delimiter_finish} = substr
-		$tokenizer->{content},
-		$tokenizer->{cursor_limit} - 1,
+	    $self->{delimiter_finish} = substr
+		$self->{content},
+		$self->{cursor_limit} - 1,
 		1;
-	    $tokenizer->{delimiter_re} = undef;
+	    $self->{delimiter_re} = undef;
 	}
 
-	if ( $tokenizer->modifier( 'e*' ) ) {
+	if ( $self->modifier( 'e*' ) ) {
 	    # With /e or /ee, the replacement portion is code. We make
 	    # it all into one big PPIx::Regexp::Token::Code, slap on the
 	    # trailing delimiter and modifiers, and return it all.
-	    push @tokens, $tokenizer->make_token(
-		$tokenizer->{cursor_limit} - $tokenizer->{cursor_curr},
+	    push @tokens, $self->make_token(
+		$self->{cursor_limit} - $self->{cursor_curr},
 		'PPIx::Regexp::Token::Code',
 		{ perl_version_introduced => MINIMUM_PERL },
 	    );
-	    $tokenizer->{cursor_limit} = length $tokenizer->{content};
-	    push @tokens, $tokenizer->make_token( 1,
+	    $self->{cursor_limit} = length $self->{content};
+	    push @tokens, $self->make_token( 1,
 		'PPIx::Regexp::Token::Delimiter' ),
-		@{ delete $tokenizer->{trailing_tokens} };
-	    $tokenizer->_set_mode( 'kaput' );
+		@{ delete $self->{trailing_tokens} };
+	    $self->_set_mode( 'kaput' );
 	} else {
 	    # Put our mode to replacement.
-	    $tokenizer->_set_mode( 'repl' );
+	    $self->_set_mode( 'repl' );
 	}
 
     }
@@ -892,6 +1011,14 @@ This option specifies the encoding of the string to be tokenized. If
 specified, an C<Encode::decode> is done on the string (or the C<content>
 of the PPI class) before it is tokenized.
 
+=item postderef boolean
+
+This option specifies whether the tokenizer recognizes postfix
+dereferencing. See the L<PPIx::Regexp|PPIx::Regexp>
+L<new()|PPIx::Regexp/new> documentation for the details.
+
+C<$PPIx::Regexp::Tokenizer::DEFAULT_POSTDEREF> is not exported.
+
 =item trace number
 
 Specifying a positive value for this option causes a trace of the
