@@ -10,9 +10,9 @@ use Scalar::Util qw{ blessed };
 
 use base qw{ Exporter };
 
-our @EXPORT_OK = qw{ __instance };
+our @EXPORT_OK = qw{ __instance __to_ordinal_en };
 
-our $VERSION = '0.042_05';
+our $VERSION = '0.043_01';
 
 sub __instance {
     my ( $object, $class ) = @_;
@@ -20,6 +20,18 @@ sub __instance {
     return $object->isa( $class );
 }
 
+sub __to_ordinal_en {
+    my ( $num ) = @_;
+    $num += 0;
+    1 == $num % 10
+	and return "${num}st";
+    2 == $num % 10
+	and return "${num}nd";
+    3 == $num % 10
+	and return "${num}rd";
+    return "${num}th";
+}
+
 1;
 
 __END__
@@ -62,6 +74,16 @@ This subroutine returns true if its first argument is an instance of the
 class specified by its second argument. Unlike C<UNIVERSAL::isa>, the
 result is always false unless the first argument is a reference.
 
+=head2 __to_ordinal_en
+
+This subroutine takes as its argument an integer and returns a string
+representing its ordinal in English. For example
+
+ say __to_ordinal_en( 17 );
+ # 17th
+
+=cut
+
 
 =head1 SEE ALSO
 
